##  Overview
Use SAP discovery to link applications in an SAP BTP, Cloud Foundry environment to new or existing fact sheets in SAP LeanIX. To enable the integration, add a platform user to the relevant Cloud Foundry organizations and spaces. Then, onboard the user to SAP LeanIX. This setup connects SAP LeanIX workspaces to SAP BTP, Cloud Foundry environments. It lets you access metadata about deployed applications, including their service bindings.
Once configured, SAP discovery also retrieves contextual information from the [SAP Cloud Management Service](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdiscovery-center.cloud.sap%2FserviceCatalog%2Fcloud-management-service%3Fregion%3Dall "https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdiscovery-center.cloud.sap%2FserviceCatalog%2Fcloud-management-service%3Fregion%3Dall") for SAP BTP.
